pub struct StateWriteConfig {
pub write_receipts: bool,
pub write_account_changesets: bool,
pub write_storage_changesets: bool,
}Expand description
Configuration for what to write to the database (MDBX) when calling
StateWriter::write_state.
Some types (receipts, changesets) may be written directly to static files instead of the database depending on the storage settings. This config allows skipping those types in the database write to avoid duplication.
Fields
write_receipts: boolWhether to write receipts to the database.
Set to false when receipts are being written to static files instead.
write_account_changesets: boolWhether to write account changesets to the database.
Set to false when account changesets are being written to static files instead.
write_storage_changesets: boolWhether to write storage changesets to the database.
Set to false when storage changesets are being written to static files instead.