pub trait BlockBodyIndicesProvider: Send {
// Required methods
fn block_body_indices(
&self,
num: u64,
) -> ProviderResult<Option<StoredBlockBodyIndices>>;
fn block_body_indices_range(
&self,
range: RangeInclusive<BlockNumber>,
) -> ProviderResult<Vec<StoredBlockBodyIndices>>;
}Expand description
Client trait for fetching block body indices related data.
Required Methods
Sourcefn block_body_indices(
&self,
num: u64,
) -> ProviderResult<Option<StoredBlockBodyIndices>>
fn block_body_indices( &self, num: u64, ) -> ProviderResult<Option<StoredBlockBodyIndices>>
Returns the block body indices with matching number from database.
Returns None if block is not found.
Sourcefn block_body_indices_range(
&self,
range: RangeInclusive<BlockNumber>,
) -> ProviderResult<Vec<StoredBlockBodyIndices>>
fn block_body_indices_range( &self, range: RangeInclusive<BlockNumber>, ) -> ProviderResult<Vec<StoredBlockBodyIndices>>
Returns the block body indices within the requested range matching number from storage.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".