HashedPostStateProvider

Trait HashedPostStateProvider 

pub trait HashedPostStateProvider {
    // Required method
    fn hashed_post_state(
        &self,
        bundle_state: &BundleState,
    ) -> ProviderResult<HashedPostState>;
}
Trait that provides the hashed state from various sources.

Required Methods

fn hashed_post_state( &self, bundle_state: &BundleState, ) -> ProviderResult<HashedPostState>

Returns the [HashedPostState] of the provided [BundleState], materializing zero-valued updates for parent storage of accounts that were destroyed but remain in the post-state.

Providers backed by an exact parent-state view also materialize terminally destroyed accounts with explicit zero-valued storage updates.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, T: 'a + HashedPostStateProvider + ?Sized> HashedPostStateProvider for &'a T

Source

fn hashed_post_state( &self, bundle_state: &BundleState, ) -> ProviderResult<HashedPostState>

Source

impl<T: HashedPostStateProvider + ?Sized> HashedPostStateProvider for Arc<T>

Source

fn hashed_post_state( &self, bundle_state: &BundleState, ) -> ProviderResult<HashedPostState>

Source

impl<T: HashedPostStateProvider + ?Sized> HashedPostStateProvider for Box<T>

Source

fn hashed_post_state( &self, bundle_state: &BundleState, ) -> ProviderResult<HashedPostState>

Implementors

Source

impl<C: Send + Sync, N: NodePrimitives> HashedPostStateProvider for NoopProvider<C, N>