StatsReader

Trait StatsReader 

pub trait StatsReader {
    // Required method
    fn count_entries<T: Table>(&self) -> ProviderResult<usize>;
}
Available on crate feature db-api only.
The trait for fetching provider statistics.

Required Methods

fn count_entries<T: Table>(&self) -> ProviderResult<usize>

Fetch the number of entries in the corresponding [Table]. Depending on the provider, it may route to different data sources other than [Table].

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a, U: 'a + StatsReader + ?Sized> StatsReader for &'a U

Source

fn count_entries<T: Table>(&self) -> ProviderResult<usize>

Source

impl<U: StatsReader + ?Sized> StatsReader for Arc<U>

Source

fn count_entries<T: Table>(&self) -> ProviderResult<usize>

Implementors