pub trait TransactionsProvider: BlockNumReader + Send {
type Transaction: Send + Sync + SignedTransaction;
// Required methods
fn transaction_id(
&self,
tx_hash: TxHash,
) -> ProviderResult<Option<TxNumber>>;
fn transaction_by_id(
&self,
id: TxNumber,
) -> ProviderResult<Option<Self::Transaction>>;
fn transaction_by_id_unhashed(
&self,
id: TxNumber,
) -> ProviderResult<Option<Self::Transaction>>;
fn transaction_by_hash(
&self,
hash: TxHash,
) -> ProviderResult<Option<Self::Transaction>>;
fn transaction_by_hash_with_meta(
&self,
hash: TxHash,
) -> ProviderResult<Option<(Self::Transaction, TransactionMeta)>>;
fn transactions_by_block(
&self,
block: BlockHashOrNumber,
) -> ProviderResult<Option<Vec<Self::Transaction>>>;
fn transactions_by_block_range(
&self,
range: impl RangeBounds<BlockNumber>,
) -> ProviderResult<Vec<Vec<Self::Transaction>>>;
fn transactions_by_tx_range(
&self,
range: impl RangeBounds<TxNumber>,
) -> ProviderResult<Vec<Self::Transaction>>;
fn senders_by_tx_range(
&self,
range: impl RangeBounds<TxNumber>,
) -> ProviderResult<Vec<Address>>;
fn transaction_sender(
&self,
id: TxNumber,
) -> ProviderResult<Option<Address>>;
}Expand description
Client trait for fetching transactions related data.
Required Associated Types
Sourcetype Transaction: Send + Sync + SignedTransaction
type Transaction: Send + Sync + SignedTransaction
The transaction type this provider reads.
Required Methods
Sourcefn transaction_id(&self, tx_hash: TxHash) -> ProviderResult<Option<TxNumber>>
fn transaction_id(&self, tx_hash: TxHash) -> ProviderResult<Option<TxNumber>>
Get internal transaction identifier by transaction hash.
This is the inverse of TransactionsProvider::transaction_by_id.
Returns None if the transaction is not found.
Sourcefn transaction_by_id(
&self,
id: TxNumber,
) -> ProviderResult<Option<Self::Transaction>>
fn transaction_by_id( &self, id: TxNumber, ) -> ProviderResult<Option<Self::Transaction>>
Get transaction by id, computes hash every time so more expensive.
Sourcefn transaction_by_id_unhashed(
&self,
id: TxNumber,
) -> ProviderResult<Option<Self::Transaction>>
fn transaction_by_id_unhashed( &self, id: TxNumber, ) -> ProviderResult<Option<Self::Transaction>>
Get transaction by id without computing the hash.
Sourcefn transaction_by_hash(
&self,
hash: TxHash,
) -> ProviderResult<Option<Self::Transaction>>
fn transaction_by_hash( &self, hash: TxHash, ) -> ProviderResult<Option<Self::Transaction>>
Get transaction by transaction hash.
Sourcefn transaction_by_hash_with_meta(
&self,
hash: TxHash,
) -> ProviderResult<Option<(Self::Transaction, TransactionMeta)>>
fn transaction_by_hash_with_meta( &self, hash: TxHash, ) -> ProviderResult<Option<(Self::Transaction, TransactionMeta)>>
Get transaction by transaction hash and additional metadata of the block the transaction was mined in
Sourcefn transactions_by_block(
&self,
block: BlockHashOrNumber,
) -> ProviderResult<Option<Vec<Self::Transaction>>>
fn transactions_by_block( &self, block: BlockHashOrNumber, ) -> ProviderResult<Option<Vec<Self::Transaction>>>
Get transactions by block id.
Sourcefn transactions_by_block_range(
&self,
range: impl RangeBounds<BlockNumber>,
) -> ProviderResult<Vec<Vec<Self::Transaction>>>
fn transactions_by_block_range( &self, range: impl RangeBounds<BlockNumber>, ) -> ProviderResult<Vec<Vec<Self::Transaction>>>
Get transactions by block range.
Sourcefn transactions_by_tx_range(
&self,
range: impl RangeBounds<TxNumber>,
) -> ProviderResult<Vec<Self::Transaction>>
fn transactions_by_tx_range( &self, range: impl RangeBounds<TxNumber>, ) -> ProviderResult<Vec<Self::Transaction>>
Get transactions by tx range.
Sourcefn senders_by_tx_range(
&self,
range: impl RangeBounds<TxNumber>,
) -> ProviderResult<Vec<Address>>
fn senders_by_tx_range( &self, range: impl RangeBounds<TxNumber>, ) -> ProviderResult<Vec<Address>>
Get Senders from a tx range.
Sourcefn transaction_sender(&self, id: TxNumber) -> ProviderResult<Option<Address>>
fn transaction_sender(&self, id: TxNumber) -> ProviderResult<Option<Address>>
Get transaction sender.
Returns None if the transaction is not found.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".