pub type StateRangeView = Box<dyn StateRangeProvider + Send + 'static>;Expand description
A reusable state range view resolved for a specific state root.
Aliased Type
pub struct StateRangeView(/* private fields */);Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 16 bytes