pub type StorageRangeResult = ProviderResult<Option<RangeResponse<(B256, U256)>>>;Expand description
Result of a StateRangeProvider::storage_range query: None if the account itself isn’t
present in the trie at the pinned state root.
Aliased Type
pub enum StorageRangeResult {
Ok(Option<RangeResponse<(FixedBytes<32>, Uint<256, 4>)>>),
Err(ProviderError),
}Variants
Ok(Option<RangeResponse<(FixedBytes<32>, Uint<256, 4>)>>)
Contains the success value
Err(ProviderError)
Contains the error value
Layout
Note: Unable to compute type layout, possibly due to this type having generic parameters. Layout can only be computed for concrete, fully-instantiated types.